@@ -1476,7 +1476,8 @@ async def download_file(request: Request):
     return FileResponse(filepath)
 
 
-if __name__ == "__main__":
+def main():
+    """Main entry point for the Python MCP Server."""
     parser = argparse.ArgumentParser(description="Python Interpreter MCP")
     parser.add_argument("--workspace", type=str, default=os.environ.get("MCP_WORKSPACE_DIR", "workspace"), help="Workspace directory for files, scripts, outputs")
     parser.add_argument("--host", type=str, default="127.0.0.1")
@@ -1494,3 +1495,7 @@ if __name__ == "__main__":
             d.mkdir(parents=True, exist_ok=True)
 
     mcp.run(transport="http", host=args.host, port=args.port)
+
+
+if __name__ == "__main__":
+    main()
